@@ -21,8 +21,12 @@ class ReaderSchema(AttrsSchema):
 
 @attr.s(auto_attribs=True, kw_only=True)
 class Badge:
-    badge_name: str = attr.ib()
-    category: str = attr.ib()
+    badge_name: str = None
+    category: Optional[str] = None
+    key: Optional[str] = None
+    icon: Optional[str] = None
+    color: Optional[str] = None
+    is_custom: Optional[str] = None
 
 
 class BadgeSchema(AttrsSchema):
